==> calligra_3.1.0+dfsg.orig.tar.xz: calligra-3.1.0/stage/part/animations/KPrAnimSet.h <==
/* This file is part of the KDE project
 * Copyright (C) 2010 Thorsten Zachmann <zachmann@kde.org>
 * Copyright (C) 2010 Benjamin Port <port.benjamin@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (  at your option ) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef KPRANIMSET_H
#define KPRANIMSET_H

#include "KPrAnimationBase.h"

class KPrAnimSet : public KPrAnimationBase
{
public:
    explicit KPrAnimSet(KPrShapeAnimation *shapeAnimation);
    virtual ~KPrAnimSet();

    virtual bool loadOdf(const KoXmlElement &element, KoShapeLoadingContext &context);
    virtual bool saveOdf(KoPASavingContext & paContext) const;
    virtual bool saveAttribute(KoPASavingContext &paContext) const;
    virtual void init(KPrAnimationCache *animationCache, int step);
protected:
    virtual void next(int currentTime);

private:
    bool m_visible;
};

#endif /* KPRANIMSET_H */

==> calligra_3.2.1+dfsg.orig.tar.xz: calligra-3.2.1/stage/part/animations/KPrAnimSet.h <==
/* This file is part of the KDE project
 * Copyright (C) 2010 Thorsten Zachmann <zachmann@kde.org>
 * Copyright (C) 2010 Benjamin Port <port.benjamin@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (  at your option ) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef KPRANIMSET_H
#define KPRANIMSET_H

#include "KPrAnimationBase.h"

class KPrAnimSet : public KPrAnimationBase
{
public:
    explicit KPrAnimSet(KPrShapeAnimation *shapeAnimation);
    ~KPrAnimSet() override;

    bool loadOdf(const KoXmlElement &element, KoShapeLoadingContext &context) override;
    bool saveOdf(KoPASavingContext & paContext) const override;
    bool saveAttribute(KoPASavingContext &paContext) const override;
    void init(KPrAnimationCache *animationCache, int step) override;
protected:
    void next(int currentTime) override;

private:
    bool m_visible;
};

#endif /* KPRANIMSET_H */
